# Regressão Linear Simples

Package educacional para entender regressão linear do zero.

## Exemplo de uso

```python
from regressaosimples import RegressaoLinearSimples

X = [1, 2, 3, 4, 5]
Y = [2, 3, 5, 4, 6]

modelo = RegressaoLinearSimples()
modelo.fit(X, Y)

print(modelo.predict([6, 7]))
